function ampDNA = ma_eqn(gspDNA)
% ampDNA is a matrix, each row is a cycle, each column is amount of DNA for a species
% first row is starting material, so number of rows = number of cycles +1.
% number of columns = number of species present

global max_num_cycles gDNA_total amp_max init_nuc_total init_nmoles_primer
global kinh fractional_primer_effect DNA_polymerase Keq_ET_ETN
global KTT KTP num_genes ktp_list pcr_bias use_species_ktp

nuc_remaining = init_nuc_total;
nmoles_primer = init_nmoles_primer;

ampDNA = zeros(max_num_cycles+1,num_genes);

ampDNA(1,:) = 2*gspDNA; %conversion of dsDNA into ssDNA; assume that both strands always perform the same

% amp_efficiency drops with more initial total gDNA
% can leave this as mass based (gDNA_total in ng) since it doesn't affect anything else 
% and doesn't represent something that is used up or changed
% kinh has units of 1/ng.

start_amp_efficiency = amp_max - kinh.*gDNA_total;

maxtpfrac = 0;

optionshere = optimset('Display','off', 'TolFun', 1e-20, 'TolX', 1e-20);

for i = 1:max_num_cycles
    
% amp efficiency drops, per species, when a species has a high chance of binding back to itself vs. binding primer    

    eff_nmoles_primer = nmoles_primer.* fractional_primer_effect;

    Peq = 0.99 * eff_nmoles_primer;
    Neq = 0.99 * nuc_remaining;
    Eeq = 0.5 * DNA_polymerase;
    
    init_guess = [Peq, Neq, Eeq];
    
    eqn2_anon = @(x)ma_eqn2(x, eff_nmoles_primer, nuc_remaining, DNA_polymerase, ampDNA(i,:));

    % use optimization routine to determine the equilibrium amounts of free primer, free nucleotide, and free enzyme
    % (DNA_polymerase) for this cycle

    [x, resnorm, residual] = lsqnonlin(eqn2_anon, init_guess, [0 0 0], [eff_nmoles_primer nuc_remaining DNA_polymerase],optionshere);
    
    pfrac = x(1)/eff_nmoles_primer;
    nfrac = x(2)/nuc_remaining;
    efrac = x(3)/DNA_polymerase;
    
    % use equilbrium amounts of free primer, free nucleotide, and free
    % enzyme found above to determine other quantities of interest
    [a,b,c,TPEN, TPE, TP, T, TT] = ma_eqn3(x, ampDNA(i,:));
    
    temp_enz_factor = TPEN ./ ampDNA(i,:);
    
    if i < 0
        cycnum = i
        gdnatot = gDNA_total
        tptotss = a
        tpenss = b
        tpess = c
        ampdnasum = sum(ampDNA(i,:))
        meantef = mean(temp_enz_factor)
        tpen1 = TPEN(1)
        tpe1 = TPE(1)
        tp1 = TP(1)
        t1 = T(1)
        tt1 = TT(1)
        ttot1 = tpen1+tpe1+tp1+t1+tt1
        ampdna1 = ampDNA(i,1)
        arrat = TPEN ./ ampDNA(i,:)
    end
    
    
% amp efficiency is modified by pcr_bias on an individual gene basis    

    amp_rate = 1 + start_amp_efficiency.*temp_enz_factor;

    % raise any amp efficiencies below 1 up to 1
    low_amp_idx = find(amp_rate < 1);
    amp_rate(low_amp_idx) = 1;

    % catastrophe check, make sure no amp efficiencies are under 1
    low_amp_idx = find(amp_rate < 1);
    if ~isempty(low_amp_idx)
        warning('amp_rate less than 1 in cycle %d\n',i)
    end
    
% actually multiply the DNA!    
    ampDNA(i+1,:) = ampDNA(i,:) .* amp_rate; % ssDNA format
    
    new_nmoles_DNA = sum(ampDNA(i+1,:) - ampDNA(i,:)); %ssDNA format
    nucs_used_this_cycle = 1500*new_nmoles_DNA;    % new_nmoles_DNA is in ssDNA format;
    
    nuc_remaining = nuc_remaining - nucs_used_this_cycle;
    nmoles_primer = nmoles_primer - new_nmoles_DNA;
    
end