

sensitivity_analysis = 0;   % 0 = no type of sensitivity analysis
                            % 1 = average sensitivity (includes multiple initial gDNA values, gDNA_total_list)
                            % 2 = sensitivity for each perturbation (1 initial gDNA value, gDNA_total_baseline)
                            % 3 = det frac and accuracy for each perturbation (1 initial gDNA value, gDNA_total_baseline)
                            % any choice but 0 will also suppress regular plots

% can't put zeros in following 3 lists
% These lists are only used if sensitivity_analysis is non-zero
perturb_amounts_avg = [0.1 -0.10];    % used for sensitivity_analysis = 1
perturb_amounts_each = [0.6 0.4 0.2 -0.2 -0.4 -0.6];    % used for sensitivity_analysis = 2 or 3
                                                        % Note that for sensitivity analysis = 3, the baseline (no perturbation)
                                                        % curve is included in the plots .  For sensitivity analysis =
                                                        % 2, a baseline plot doesn't make sense (it would be zero
                                                        % everywhere) so it is not in the plot.  So, if sensitivity analysis = 3, 
                                                        % one should put a gap in the list for uniform steps on plot 
                                                        % (e.g., [.4 .2  -.2 -.4]), whereas for sensitivity analysis = 2, uniform 
                                                        % steps on plot occur if no gap is used in list (e.g. [.3 .1 -.1 -.3]).

perturb_amounts_ar = [0.333333 0.2 0.1 -0.1 -0.2 -0.333333];     % used for sensitivity_analysis = 2 or 3 for max amplification rate
                                                                 % set so amp rate doesn't go over 2.0

num_repeats = 10;

max_num_cycles = 40;

gDNA_total_list = [1 3 10 30 100 300 1000];  % will simulate results for 7 different starting amounts of gDNA, ng
%gDNA_total_list = [1:1000];
gDNA_total_baseline = 10;

pcr_vol = 50e-6;    % volume of reaction, in liters
init_nuc_conc = 8e-4;   % total raw material nucleotides in PCR reaction, M
frac_gsp_of_total = .00246; % mass fraction of 16S rDNA in genome;

init_nmoles_primer = 200*pcr_vol*2;   % each primer - 200nM
                                      % multiply by 2 to get total primer c% (corresponds to ssDNA calculations)
fractional_primer_effect = 0.508;     % degeneracy in forward primer (4 positions)leads to 0.508 factor
                                      % degeneracy in reverse primer (1 position) gives factor of 0.875)
                                      % assume fractional effect is the worse b/w For and Rev primers                                      

DNA_polymerase = 2.66e-9 * 1e9 * pcr_vol ;   % nanomoles of enzyme

amp_max = 0.75;  % max amplification efficiency based on experimental data

num_genes = 400;        % total number of bacterial species in the sample

gspDNA_init_range = 4;     % orders of magnitude over which initial gsp DNA can vary
dist_pow = 2;       % power for scaling initial distribution of gspDNA.  1 = exponential 10^x, 2 = 10^(x^2), 3 = 10^(x^3), etc.

%kinh = coefficient for the inhibition effect of gDNA mass, units of 1/ng
kinh = 0.00025;

KTT = 1e10/(pcr_vol * 1e9); % constant for template-template annealing; value according to Mehra 2005

KTP_mean = 1.12e8/(pcr_vol * 1e9); % constant for template-primer annealing
lognorm_sigma = 1.74;       % use lognormal distribution for ktp values.  Chosen because negative values aren't possible.
                                % This sigma value is the standard sigma used in the definition of a lognormal distribution
                                % It is dimensionless
                                
Keq_ET = 1e8;       % M-1 - per PCR modeling file
Keq_ETN = 1.75e6;   % M-1 - per PCR modeling file

det_limit_mean = 0.005;   % ng; detection limit of microarray
det_limit_sd = 0.002;     % ng; random variability in detection limit for different probesets
det_lim_min = 0.001;      % minimum detection limit

accuracy_factor = 1.5;  % used for plots


% parameters below this line are generally not meant to be edited
KET = Keq_ET / (pcr_vol * 1e9);
KETN = Keq_ETN / (pcr_vol * 1e9);

ng_per_nmole_ss_nuc = 310;  % single-stranded chain of nucleotides
init_nuc_total = init_nuc_conc*pcr_vol*1e9;   % total raw material nucleotides in PCR reaction, nanomoles

Keq_ET_ETN = Keq_ET*Keq_ETN/(pcr_vol^2 * 1e9^2);    % in units of nanomoles-1
