%%% PLOTTING %%%

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultTextFontName','Times New Roman')
fignum = 0;

linecolorlist = [0 0 0;
                 0 0 0;
                 0 0 0;
                 0 0 0;
                .7 .7 .7;
                .7 .7 .7;
                .7 .7 .7;
                .7 .7 .7];

linestylelist = {':','--','-.','-','-.','--','-',':'};     


if sensitivity_analysis == 0        % regular plots

    [nng,nnc] = meshgrid(gDNA_total_list,[0:max_num_cycles]);

    fignum = fignum + 1;
    figure('Name','Figure 1A');
    colormap(jet(512))
    contourf(nng,nnc,det_frac, 512, 'LineStyle','none');
    title('Species detection fraction')
    xlabel('initial gDNA loading (ng)')
    ylabel('number of PCR cycles')
    set(gca,'XScale','log')
    caxis([0.0 1.0])
    colorbar

    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]

    fignum = fignum + 1;
    figure('Name','Figure 1B');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],det_frac,'LineWidth',2)
     xlabel('number of PCR cycles')
     ylabel('detection fraction')
    legend('1 ng','3 ng','10 ng','30 ng','100 ng','300 ng','1000 ng', 'Location', 'SouthEast')
    title('Species detection fraction')

    fignum = fignum + 1;
    figure('Name','Figure 1C');
    colormap(flipud(jet(512))) 
    contourf(nng,nnc,all_acc_avg, 512,'LineStyle','none', 'Fill','on')
    xlabel('initial gDNA loading (ng)')
    ylabel('number of PCR cycles')
    set(gca,'XScale','log')
    colorbar
    title('Accuracy of species abundance measurements')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure 1D');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],all_acc_avg,'LineWidth',2)
    xlabel('number of PCR cycles')
    ylabel('abundance measurement accuracy, lower is better')
    legend('1 ng','3 ng','10 ng','30 ng','100 ng','300 ng','1000 ng')
    title('Accuracy of species abundance measurements')

    % Average AR for different starting amounts
    fignum = fignum + 1;
    figure('Name','Figure S1');
    plot([1:max_num_cycles],amp_mean,'LineWidth',2);
    legend('1 ng','3 ng','10 ng','30 ng','100 ng','300 ng','1000 ng')
    xlabel('number of cycles')
    ylabel('amplification rate')
    title('Average amplification rate')

    % XY plot graph of relative % of amplified 16S DNA in sample
    %ampDNA_all = sum(ampDNA_postpcr_expt');
    rel_16s_fraction = ampDNA_all ./ (DNA_total_postpcr_expt_all*2);
    fignum = fignum + 1;
    figure('Name','Figure S2');
    plot([0:max_num_cycles],rel_16s_fraction,'LineWidth',2)
    legend('1 ng','3 ng','10 ng','30 ng','100 ng','300 ng','1000 ng', 'Location', 'SouthEast')
    xlabel('number of PCR cycles')
    ylabel('fraction')
    title('Relative fraction of amplified 16S DNA in sample')
    set(gca,'YScale','log')

    % Number of reactions needed to combine to get to 1500ng load
    fignum = fignum + 1;
    figure('Name','Figure S3');
    set(gca,'NextPlot','replacechildren')
    plot([0:max_num_cycles],num_expmts_to_combine,'LineWidth',2)
    xlabel('number of PCR cycles')
    ylabel('number of experiments to combine')
    legend('1 ng','3 ng','10 ng','30 ng','100 ng','300 ng','1000 ng')
    title('Number of reactions to combine to achieve 1500 ng load')
    set(gca,'YScale','log')

    %  PCR reaction yield - 2D plot
    %nuc_used = frac_nuc_used * 19500;
    nuc_used = 2 * 1500./num_expmts_to_combine; % factor of 2 removes purification loss from yield calculations
    fignum = fignum + 1;
    figure('Name','Figure S4');
    colormap(jet(512))
    contourf(nng,nnc,nuc_used, 512, 'LineStyle','none');
    xlabel('initial gDNA loading (ng)')
    ylabel('number of PCR cycles')
    title('Total yield of single PCR reaction, ng')
    set(gca,'XScale','log')
    caxis([0.0 max(nuc_used(:))])
    colorbar
    

%    fignum = fignum + 1;
%    figure('Name','Figure S5');
%    set(gca,'NextPlot','replacechildren')
%    light_to_dark = [.7 .7 .7;
%                     0 0 0];
%    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
%    subplot(3,1,1)
%    plot([0:max_num_cycles],frac_per_species(:,400,7),'LineWidth',2,'Color','black')
%    title({'Fractional abundance vs. cycle number'; ' ';'Most abundant species'})
%    axis([1, 40, 0.04, 0.045])
%    set(gca,'YTick',[0.04, 0.045])
%    subplot(3,1,2)
%    plot([0:max_num_cycles],frac_per_species(:,200,7),'LineWidth',2,'Color','black')
%    title('Mid abundant species')
%    axis([1, 40, 0.00004, 0.000045])
%    set(gca,'YTick',[0.00004, 0.000045])
%    subplot(3,1,3)
%    plot([0:max_num_cycles],frac_per_species(:,1,7),'LineWidth',2,'Color','black')
%    title('Least abundant species')
%    axis([1, 40, 0.000004, 0.0000045])
%    set(gca,'YTick',[0.000004, 0.0000045])
%    xlabel('Number of PCR cycles')
   

elseif sensitivity_analysis == 1    % sensitivity, average of perturbations

    % amp max

    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA1');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_df_ampmax,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Detection Fraction to Maximum Amplification Rate')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA2');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_aa_ampmax,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Accuracy to Maximum Amplification Rate')


    % kinh    
    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA3');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_df_kinh,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Detection Fraction to PCR Inhibition')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA4');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_aa_kinh,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Accuracy to PCR Inhibition')

    % init_nmoles_primer    
    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA5');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_df_inp,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Detection Fraction to Init nMoles Primer')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA6');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_aa_inp,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Accuracy to Init nMoles Primer')

    % Number of Species
    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA7');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_df_ng,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Detection Fraction to Number of Species')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA8');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_aa_ng,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Accuracy to Number of Species')
    
    % lognorm_sigma
    % XY linear detection plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA9');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_df_lns,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Detection Fraction to KTP lognormal spread')

    % XY linear accuracy plot - lines for [1/3/10/30/100/300/1000ng]
    fignum = fignum + 1;
    figure('Name','Figure SA10');
    set(gca,'NextPlot','replacechildren')
    light_to_dark = [.7 .7 .7;
                     0 0 0];
    set(gca,'ColorOrder',light_to_dark,'LineStyleOrder',{'-','--',':','-.'});
    plot([0:max_num_cycles],avg_sens_aa_lns,'LineWidth',2)
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend('1','3','10','30','100','300','1000', 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Initial gDNA');    
    title('Sensitivity of Accuracy to KTP lognormal spread')
    
elseif sensitivity_analysis == 2      % sensitivity, multiple perturbations, 1 initial gDNA
    
    % amp max

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SB1');
    clear legca
    hold all
    for epa = 1:numARperturbamounts
        plot([0:max_num_cycles],sens_detfrac_ampmax{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        legca{epa} = num2str(1 + ampmaxlist(epa));
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Max Amp Rate');    
    title('Sensitivity of Detection Fraction to Maximum Amplification Rate')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SB2');
    hold all
    for epa = 1:numARperturbamounts
        plot([0:max_num_cycles],sens_accavg_ampmax{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Max Amp Rate');    
    title('Sensitivity of Accuracy to Maximum Amplification Rate')
    hold off

    % kinh

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SB3');
    clear legca
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_detfrac_kinh{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        legca{epa} = num2str(kinhlist(epa));
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Kinh Value');    
    title('Sensitivity of Detection Fraction to PCR Inhibition')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SB4');
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_accavg_kinh{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Kinh Value');    
    title('Sensitivity of Accuracy to PCR Inhibition')
    hold off

    % Init nMoles Primer

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SB5');
    clear legca
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_detfrac_inp{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        legca{epa} = num2str(inplist(epa)/pcr_vol);
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Init Primer Conc (nM)');    
    title('Sensitivity of Detection Fraction to Init nMoles Primer')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SB6');
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_accavg_inp{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Init Primer Conc (nM)');    
    title('Sensitivity of Accuracy to Init nMoles Primer')
    hold off

    % Number of Species

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SB7');
    clear legca
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_detfrac_ng{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        legca{epa} = num2str(nglist(epa));
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Number of Species');    
    title('Sensitivity of Detection Fraction to Number of Species')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SB8');
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_accavg_ng{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Number of Species');    
    title('Sensitivity of Accuracy to Number of Species')
    hold off
    
    % lognorm_sigma

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SB9');
    clear legca
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_detfrac_lns{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        legca{epa} = [num2str(lognormsigmalist(epa),'%11.3f') ' / ' num2str(armedabs_frac{epa},'%11.2f') '%'];
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Lognorm Sigma / amp rate median of abs variance');    
    title('Sensitivity of Detection Fraction to KTP lognormal spread')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SB10');
    hold all
    for epa = 1:numperturbamounts
        plot([0:max_num_cycles],sens_accavg_lns{epa},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
    end
    xlabel('number of cycles')
    ylabel('sensitivity')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Lognorm Sigma / amp rate median of abs variance');    
    title('Sensitivity of Accuracy to KTP lognormal spread')
    hold off
    
elseif sensitivity_analysis == 3      % detfrac and accavg, multiple perturbations, 1 initial gDNA
    
    pa_list = sort([perturb_amounts 0],'descend');
    paAR_list = sort([perturb_amounts_ar 0],'descend');

    
    % amp max

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SC1');
    clear legca 
    hold all
    for epa = 1:numARperturbamounts+1
        idx = find(perturb_amounts_ar == paAR_list(epa));
        if idx
            plot([0:max_num_cycles],detfrac_ampmax{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(1 + ampmaxlist(idx));
        else
            plot([0:max_num_cycles],det_frac_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(1 + amp_max_baseline);
        end
    end
    xlabel('number of PCR cycles')
    ylabel('detection fraction')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Max amp rate');    
    title('Detection fraction for multiple maximum amplification rates')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SC2');
    hold all
    for epa = 1:numARperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],accavg_ampmax{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        else
            plot([0:max_num_cycles],acc_avg_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        end
    end
    xlabel('number of PCR cycles')
    ylabel('abundance measurement accuracy, lower is better')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Max amp rate');    
    title('Accuracy for multiple maximum mmplification rates')
    hold off

    % kinh

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SC3');
    clear legca
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],detfrac_kinh{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(kinhlist(idx));
        else
            plot([0:max_num_cycles],det_frac_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(kinh_baseline);
        end
    end
    xlabel('number of cycles')
    ylabel('Detection Fraction')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Kinh Value');    
    title('Detection Fraction for Multiple PCR Inhibition Values')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SC4');
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],accavg_kinh{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        else
            plot([0:max_num_cycles],acc_avg_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        end
    end
    xlabel('number of cycles')
    ylabel('Accuracy, lower is better')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Kinh Value');    
    title('Accuracy for Multiple PCR Inhibition Values')
    hold off

    % Init nMoles Primer

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SC5');
    clear legca
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],detfrac_inp{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(inplist(idx)/pcr_vol);
        else
            plot([0:max_num_cycles],det_frac_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(init_nmoles_primer_baseline/pcr_vol);
        end
    end
    xlabel('number of PCR cycles')
    ylabel('detection fraction')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Primer conc (nM)');    
    title('Detection fraction for multiple initial primer concetrations')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SC6');
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],accavg_inp{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        else
            plot([0:max_num_cycles],acc_avg_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        end
    end
    xlabel('number of PCR cycles')
    ylabel('abundance measurement accuracy, lower is better')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Primer conc (nM)');    
    title('Accuracy for multiple initial primer concetrations')
    hold off

    % Number of Species

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SC7');
    clear legca
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],detfrac_ng{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(nglist(idx));
        else
            plot([0:max_num_cycles],det_frac_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
            legca{epa} = num2str(num_genes_baseline);
        end
    end
    xlabel('number of PCR cycles')
    ylabel('detection fraction')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Number of species');    
    title('Detection fraction for multiple numbers of community members')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SC8');
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],accavg_ng{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        else
            plot([0:max_num_cycles],acc_avg_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        end
    end
    xlabel('number of PCR cycles')
    ylabel('abundance measurement accuracy, lower is better')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Number of species');    
    title('Accuracy for for multiple numbers of community members')
    hold off
    
    % lognormal_sigma

    % XY linear detection plot - lines for perturb amounts
    fignum = fignum + 1;
    figure('Name','Figure SC9');
    clear legca
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],detfrac_lns{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
%                legca{epa} = [num2str(lognormsigmalist(idx),'%11.3f') ' / ' num2str(arsd_frac{idx},'%11.2f') '%'];
            legca{epa} = [num2str(lognormsigmalist(idx),'%11.3f') ' / ' num2str(armedabs_frac{idx},'%11.2f') '%'];
        else
            plot([0:max_num_cycles],det_frac_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
%                legca{epa} = [num2str(lognorm_sigma_baseline,'%11.3f') ' / ' num2str(arsd_frac_baseline,'%11.2f') '%'];
            legca{epa} = [num2str(lognorm_sigma_baseline,'%11.3f') ' / ' num2str(arabsmed_baseline,'%11.2f') '%'];
        end
    end
    xlabel('number of PCR cycles')
    ylabel('detection fraction')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Lognorm sigma / AR median bias');    
    title('Detection fraction for multiple PCR bias levels')
    hold off

    % XY linear accuracy plot
    fignum = fignum + 1;
    figure('Name','Figure SC10');
    hold all
    for epa = 1:numperturbamounts+1
        idx = find(perturb_amounts == pa_list(epa));
        if idx
            plot([0:max_num_cycles],accavg_lns{idx},'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        else
            plot([0:max_num_cycles],acc_avg_baseline,'LineWidth',2, 'Color',linecolorlist(mod(epa-1,8)+1,:),'LineStyle',linestylelist{mod(epa-1,8)+1})
        end
    end
    xlabel('number of PCR cycles')
    ylabel('abundance measurement accuracy, lower is better')
    lh = legend(legca, 'Location', 'Best');
    lv = get(lh,'title');
    set(lv,'string','Lognorm sigma / AR median bias');    
    title('Accuracy for multiple PCR bias levels')
    hold off
    
end