
numperturbamounts = length(perturb_amounts);
numARperturbamounts = length(perturb_amounts_ar);

amp_max_baseline = amp_max;
kinh_baseline = kinh;
init_nmoles_primer_baseline = init_nmoles_primer;
num_genes_baseline = num_genes;
lognorm_sigma_baseline = lognorm_sigma;

ampmaxlist = amp_max_baseline * (1 + perturb_amounts_ar);
kinhlist = kinh_baseline * (1 + perturb_amounts);
inplist = init_nmoles_primer_baseline * (1 + perturb_amounts);
nglist = num_genes_baseline * (1 + perturb_amounts);
lognormsigmalist = lognorm_sigma_baseline * (1 + perturb_amounts);

% run once with baseline values
randnstate = randn('state');
ma_runsim
det_frac_baseline = det_frac;
acc_avg_baseline = all_acc_avg;
arabsmed_baseline = arabsvariance;

% perturb amp max

clear sens_detfrac_ampmax
clear sens_accavg_ampmax
clear detfrac_ampmax
clear accavg_ampmax
for pa = 1:numARperturbamounts
    randn('state',randnstate)     % need to reset random number generate to same place each time, 
                                  % else comparing different species
    amp_max = ampmaxlist(pa);
    ma_runsim
    detfrac_ampmax{pa} = det_frac;
    accavg_ampmax{pa} = all_acc_avg;
    sens_detfrac_ampmax{pa} = ((det_frac - det_frac_baseline) ./ det_frac_baseline) ./ perturb_amounts_ar(pa);
    sens_accavg_ampmax{pa} = ((all_acc_avg - acc_avg_baseline) ./ acc_avg_baseline) ./ perturb_amounts_ar(pa);
end

if sensitivity_analysis == 1
    numrows = size(det_frac,1);
    numcols = size(det_frac,2);
    avg_sens_df_ampmax = zeros(numrows,numcols);
    avg_sens_aa_ampmax = zeros(numrows,numcols);
    for amprow = 1:numrows
        for ampcol = 1:numcols
            runningtotal1 = 0;
            runningtotal2 = 0;
            for pa = 1:numARperturbamounts
                runningtotal1 = runningtotal1 + sens_detfrac_ampmax{pa}(amprow,ampcol);
                runningtotal2 = runningtotal2 + sens_accavg_ampmax{pa}(amprow,ampcol);
            end
            avg_sens_df_ampmax(amprow,ampcol) = runningtotal1 / numARperturbamounts;
            avg_sens_aa_ampmax(amprow,ampcol) = runningtotal2 / numARperturbamounts;
        end
    end
end
amp_max = amp_max_baseline;


% perturb kinh

clear sens_detfrac_kinh
clear sens_accavg_kinh
clear detfrac_kinh
clear accavg_kinh
for pa = 1:numperturbamounts
    randn('state',randnstate)     % need to reset random number generate to same place each time, 
                                  % else comparing different species
    kinh = kinhlist(pa);
    ma_runsim
    detfrac_kinh{pa} = det_frac;
    accavg_kinh{pa} = all_acc_avg;
    sens_detfrac_kinh{pa} = ((det_frac - det_frac_baseline) ./ det_frac_baseline) ./ perturb_amounts(pa);
    sens_accavg_kinh{pa} = ((all_acc_avg - acc_avg_baseline) ./ acc_avg_baseline) ./ perturb_amounts(pa);
end

if sensitivity_analysis == 1
    numrows = size(det_frac,1);
    numcols = size(det_frac,2);
    avg_sens_df_kinh = zeros(numrows,numcols);
    avg_sens_aa_kinh = zeros(numrows,numcols);
    for amprow = 1:numrows
        for ampcol = 1:numcols
            runningtotal1 = 0;
            runningtotal2 = 0;
            for pa = 1:numperturbamounts
                runningtotal1 = runningtotal1 + sens_detfrac_kinh{pa}(amprow,ampcol);
                runningtotal2 = runningtotal2 + sens_accavg_kinh{pa}(amprow,ampcol);
            end
            avg_sens_df_kinh(amprow,ampcol) = runningtotal1 / numperturbamounts;
            avg_sens_aa_kinh(amprow,ampcol) = runningtotal2 / numperturbamounts;
        end
    end
end
kinh = kinh_baseline;

% perturb initial amount of primer

clear sens_detfrac_inp
clear sens_accavg_inp
clear detfrac_inp
clear accavg_inp
for pa = 1:numperturbamounts
    randn('state',randnstate)     % need to reset random number generate to same place each time, 
                                  % else comparing different species
    init_nmoles_primer = inplist(pa);
    ma_runsim
    detfrac_inp{pa} = det_frac;
    accavg_inp{pa} = all_acc_avg;
    sens_detfrac_inp{pa} = ((det_frac - det_frac_baseline) ./ det_frac_baseline) ./ perturb_amounts(pa);
    sens_accavg_inp{pa} = ((all_acc_avg - acc_avg_baseline) ./ acc_avg_baseline) ./ perturb_amounts(pa);
end

if sensitivity_analysis == 1
    numrows = size(det_frac,1);
    numcols = size(det_frac,2);
    avg_sens_df_inp = zeros(numrows,numcols);
    avg_sens_aa_inp = zeros(numrows,numcols);
    for amprow = 1:numrows
        for ampcol = 1:numcols
            runningtotal1 = 0;
            runningtotal2 = 0;
            for pa = 1:numperturbamounts
                runningtotal1 = runningtotal1 + sens_detfrac_inp{pa}(amprow,ampcol);
                runningtotal2 = runningtotal2 + sens_accavg_inp{pa}(amprow,ampcol);
            end
            avg_sens_df_inp(amprow,ampcol) = runningtotal1 / numperturbamounts;
            avg_sens_aa_inp(amprow,ampcol) = runningtotal2 / numperturbamounts;
        end
    end
end
init_nmoles_primer = init_nmoles_primer_baseline;

% perturb species number

clear sens_detfrac_ng
clear sens_accavg_ng
clear detfrac_ng
clear accavg_ng
for pa = 1:numperturbamounts
    randn('state',randnstate)     % need to reset random number generate to same place each time, 
                                  % else comparing different species
    num_genes = round(nglist(pa));
    ma_runsim
    detfrac_ng{pa} = det_frac;
    accavg_ng{pa} = all_acc_avg;
    sens_detfrac_ng{pa} = ((det_frac - det_frac_baseline) ./ det_frac_baseline) ./ perturb_amounts(pa);
    sens_accavg_ng{pa} = ((all_acc_avg - acc_avg_baseline) ./ acc_avg_baseline) ./ perturb_amounts(pa);
end

if sensitivity_analysis == 1
    numrows = size(det_frac,1);
    numcols = size(det_frac,2);
    avg_sens_df_ng = zeros(numrows,numcols);
    avg_sens_aa_ng = zeros(numrows,numcols);
    for amprow = 1:numrows
        for ampcol = 1:numcols
            runningtotal1 = 0;
            runningtotal2 = 0;
            for pa = 1:numperturbamounts
                runningtotal1 = runningtotal1 + sens_detfrac_ng{pa}(amprow,ampcol);
                runningtotal2 = runningtotal2 + sens_accavg_ng{pa}(amprow,ampcol);
            end
            avg_sens_df_ng(amprow,ampcol) = runningtotal1 / numperturbamounts;
            avg_sens_aa_ng(amprow,ampcol) = runningtotal2 / numperturbamounts;
        end
    end
end
num_genes = num_genes_baseline;

% perturb sigma value of lognorm distribution for KTP

clear sens_detfrac_lns
clear sens_accavg_lns
clear detfrac_lns
clear accavg_lns
clear armedabs_frac
for pa = 1:numperturbamounts
    randn('state',randnstate)     % need to reset random number generate to same place each time, 
                                  % else comparing different species
    lognorm_sigma = lognormsigmalist(pa);
    ma_runsim
    detfrac_lns{pa} = det_frac;
    accavg_lns{pa} = all_acc_avg;
    armedabs_frac{pa} = arabsvariance;
    sens_detfrac_lns{pa} = ((det_frac - det_frac_baseline) ./ det_frac_baseline) ./ perturb_amounts(pa);
    sens_accavg_lns{pa} = ((all_acc_avg - acc_avg_baseline) ./ acc_avg_baseline) ./ perturb_amounts(pa);
end

if sensitivity_analysis == 1
    numrows = size(det_frac,1);
    numcols = size(det_frac,2);
    avg_sens_df_lns = zeros(numrows,numcols);
    avg_sens_aa_lns = zeros(numrows,numcols);
    for amprow = 1:numrows
        for ampcol = 1:numcols
            runningtotal1 = 0;
            runningtotal2 = 0;
            for pa = 1:numperturbamounts
                runningtotal1 = runningtotal1 + sens_detfrac_lns{pa}(amprow,ampcol);
                runningtotal2 = runningtotal2 + sens_accavg_lns{pa}(amprow,ampcol);
            end
            avg_sens_df_lns(amprow,ampcol) = runningtotal1 / numperturbamounts;
            avg_sens_aa_lns(amprow,ampcol) = runningtotal2 / numperturbamounts;
        end
    end
end
lognorm_sigma = lognorm_sigma_baseline;
    
